<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE xsl:stylesheet SYSTEM "ui.dtd">
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output doctype-system="about:legacy-compat" method="html" indent="no" encoding="utf-8"/>

<xsl:template match="part[@name='profile']">
  <style>
    &css_form;
  </style>

  <div class="form-cnt">
    <xsl:apply-templates select="limit"/>
    <xsl:apply-templates select="used"/>
    <xsl:apply-templates select="depth-max"/>
    <xsl:apply-templates select="copy-to"/>

    <form enctype="multipart/form-data" method="post">

      <div class="form-cnt__form-ctl">
        <div class="form-ctl__caption">
          <xsl:value-of select="$strings/profile-password"/>
        </div>
        <div class="form-ctl__value">
          <input class="form-ctl__value__input" type="password" maxlength="255" name="password"/>
        </div>
      </div>
      <div class="form-cnt__form-ctl">
        <div class="form-ctl__caption">
          <xsl:value-of select="$strings/profile-password2"/>
        </div>
        <div class="form-ctl__value">
          <input class="form-ctl__value__input" type="password" maxlength="255" name="password2"/>
        </div>
      </div>

      <xsl:apply-templates select="vcard"/>

      <div class="form-apply-cnt">
        <input class="form-apply" type="submit" value="{$strings/submit}"/>
      </div>
    </form>
  </div>
</xsl:template>

<xsl:template match="limit|used|depth-max|copy-to">
  <xsl:if test="not(.='0' or .='' or .='0 B')">
    <xsl:variable name="prop" select="local-name()"/>
    <div class="form-cnt__form-ctl">
      <div class="form-ctl__caption">
        <xsl:value-of select="$strings/profile[@prop=$prop]"/>
      </div>
      <div class="form-ctl__value">
        <xsl:value-of select="."/>
      </div>
    </div>
  </xsl:if>
</xsl:template>



<xsl:template match="login-time">
  <div class="form-cnt__form-ctl">
    <div class="form-ctl__caption">
      <xsl:value-of select="$strings/profile[@prop='login-time']"/>
    </div>
    <div class="form-ctl__value">

      <!-- Date -->

      <xsl:variable name="date-format" select="document(concat('locale/',$lang,'.xml'))/locale/date"/>

      <xsl:variable name="year" select="substring(.,1,4)"/>
      <xsl:variable name="month" select="substring(.,6,2)"/>
      <xsl:variable name="day" select="substring(.,9,2)"/>

      <xsl:variable name="date-fmt-1" select="substring($date-format,1,1)"/>
      <xsl:variable name="date-fmt-2" select="substring($date-format,3,1)"/>
      <xsl:variable name="date-fmt-3" select="substring($date-format,5,1)"/>

      <xsl:choose>
        <xsl:when test="$date-fmt-1='Y'"><xsl:value-of select="$year"/></xsl:when>
        <xsl:when test="$date-fmt-1='M'"><xsl:value-of select="$month"/></xsl:when>
        <xsl:when test="$date-fmt-1='D'"><xsl:value-of select="$day"/></xsl:when>
      </xsl:choose>
      <xsl:value-of select="substring($date-format,2,1)"/>
      <xsl:choose>
        <xsl:when test="$date-fmt-2='Y'"><xsl:value-of select="$year"/></xsl:when>
        <xsl:when test="$date-fmt-2='M'"><xsl:value-of select="$month"/></xsl:when>
        <xsl:when test="$date-fmt-2='D'"><xsl:value-of select="$day"/></xsl:when>
      </xsl:choose>
      <xsl:value-of select="substring($date-format,4,1)"/>
      <xsl:choose>
        <xsl:when test="$date-fmt-3='Y'"><xsl:value-of select="$year"/></xsl:when>
        <xsl:when test="$date-fmt-3='M'"><xsl:value-of select="$month"/></xsl:when>
        <xsl:when test="$date-fmt-3='D'"><xsl:value-of select="$day"/></xsl:when>
      </xsl:choose>

      <xsl:text> </xsl:text>

      <!-- Time -->

      <xsl:variable name="h" select="substring(.,12,2)"/>
      <xsl:variable name="m" select="substring(.,15,2)"/>

      <xsl:choose>
        <xsl:when test="document(concat('locale/',$lang,'.xml'))/locale/time='12'">

          <!-- 12-hour format -->

          <xsl:choose>
            <xsl:when test="$h = 0">
              <xsl:text>12</xsl:text>
            </xsl:when>
            <xsl:when test="$h &lt; 12">
              <xsl:value-of select="$h"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$h - 12"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:text>:</xsl:text>
          <xsl:value-of select="$m"/>
          <xsl:choose>
            <xsl:when test="$h &lt; 12"> AM</xsl:when>
            <xsl:otherwise> PM</xsl:otherwise>
          </xsl:choose>

        </xsl:when>
        <xsl:otherwise>

          <!-- 24-hour format -->

          <xsl:value-of select="$h"/>
          <xsl:text>:</xsl:text>
          <xsl:value-of select="$m"/>
        </xsl:otherwise>
      </xsl:choose>

    </div>  <!-- form-ctl__value -->
  </div>  <!-- form-cnt__form-ctl -->

</xsl:template>  <!-- login-time -->

</xsl:stylesheet>
